@@ -34,7 +34,7 @@ pub struct PythonSpy {
     pub version: Version,
     pub interpreter_address: usize,
     pub threadstate_address: usize,
-    pub python_filename: String,
+    pub python_filename: std::path::PathBuf,
     pub version_string: String,
     pub config: Config,
     #[cfg(unwind)]
@@ -203,7 +203,7 @@ impl PythonSpy {
             thread_activity.insert(threadid, thread.active()?);
         }
 
-        // Lock the process if appropiate. Note we have to lock AFTER getting the thread
+        // Lock the process if appropriate. Note we have to lock AFTER getting the thread
         // activity status from the OS (otherwise each thread would report being inactive always).
         // This has the potential for race conditions (in that the thread activity could change
         // between getting the status and locking the thread, but seems unavoidable right now
@@ -289,7 +289,7 @@ impl PythonSpy {
 
             traces.push(trace);
 
-            // This seems to happen occasionally when scanning BSS addresses for valid interpeters
+            // This seems to happen occasionally when scanning BSS addresses for valid interpreters
             if traces.len() > 4096 {
                 return Err(format_err!("Max thread recursion depth reached"));
             }
@@ -558,7 +558,7 @@ fn get_python_version(python_info: &PythonProcessInfo, process: &remoteprocess::
 
     // the python_filename might have the version encoded in it (/usr/bin/python3.5 etc).
     // try reading that in (will miss patch level on python, but that shouldn't matter)
-    info!("Trying to get version from path: {}", python_info.python_filename);
+    info!("Trying to get version from path: {}", python_info.python_filename.display());
     let path = Path::new(&python_info.python_filename);
     if let Some(python) = path.file_name() {
         if let Some(python) = python.to_str() {
@@ -688,7 +688,7 @@ fn check_interpreter_addresses(addrs: &[usize],
         Err(format_err!("Failed to find a python interpreter in the .data section"))
     }
 
-    // different versions have different layouts, check as appropiate
+    // different versions have different layouts, check as appropriate
     match version {
         Version{major: 2, minor: 3..=7, ..} => check::<v2_7_15::_is>(addrs, maps, process),
         Version{major: 3, minor: 3, ..} => check::<v3_3_7::_is>(addrs, maps, process),
@@ -716,7 +716,7 @@ pub struct PythonProcessInfo {
     // be in a libpython.so file instead of the executable. support that.
     libpython_binary: Option<BinaryInfo>,
     maps: Vec<MapRange>,
-    python_filename: String,
+    python_filename: std::path::PathBuf,
     #[cfg(target_os="linux")]
     dockerized: bool,
 }
@@ -728,6 +728,7 @@ impl PythonProcessInfo {
 
         #[cfg(windows)]
         let filename = filename.to_lowercase();
+
         #[cfg(windows)]
         let is_python_bin = |pathname: &str| pathname.to_lowercase() == filename;
 
@@ -740,16 +741,19 @@ impl PythonProcessInfo {
         for map in &maps {
             debug!("map: {:016x}-{:016x} {}{}{} {}", map.start(), map.start() + map.size(),
                 if map.is_read() {'r'} else {'-'}, if map.is_write() {'w'} else {'-'}, if map.is_exec() {'x'} else {'-'},
-                map.filename().as_ref().unwrap_or(&"".to_owned()));
+                map.filename().unwrap_or(&std::path::PathBuf::from("")).display());
         }
 
         // parse the main python binary
         let (python_binary, python_filename) = {
             // Get the memory address for the executable by matching against virtual memory maps
             let map = maps.iter()
-                .find(|m| if let Some(pathname) = &m.filename() {
-                    is_python_bin(pathname) && m.is_exec()
-                } else {
+                .find(|m| {
+                    if let Some(pathname) = m.filename() {
+                        if let Some(pathname) = pathname.to_str() {
+                            return is_python_bin(pathname) && m.is_exec();
+                        }
+                    }
                     false
                 });
 
@@ -764,6 +768,8 @@ impl PythonProcessInfo {
                 }
             };
 
+            let filename = std::path::PathBuf::from(filename);
+
             // TODO: consistent types? u64 -> usize? for map.start etc
             #[allow(unused_mut)]
             let python_binary = parse_binary(process.pid, &filename, map.start() as u64, map.size() as u64, true)
@@ -776,7 +782,7 @@ impl PythonProcessInfo {
                             .map_err(|err| err.into())
                     }
 
-                    // For OSX, need to adjust main binary symbols by substracting _mh_execute_header
+                    // For OSX, need to adjust main binary symbols by subtracting _mh_execute_header
                     // (which we've added to by map.start already, so undo that here)
                     #[cfg(target_os = "macos")]
                     {
@@ -800,16 +806,19 @@ impl PythonProcessInfo {
         // likewise handle libpython for python versions compiled with --enabled-shared
         let libpython_binary = {
             let libmap = maps.iter()
-                .find(|m| if let Some(ref pathname) = &m.filename() {
-                    is_python_lib(pathname) && m.is_exec()
-                } else {
+                .find(|m| {
+                    if let Some(pathname) = m.filename() {
+                        if let Some(pathname) = pathname.to_str() {
+                            return is_python_lib(pathname) && m.is_exec();
+                        }
+                    }
                     false
                 });
 
             let mut libpython_binary: Option<BinaryInfo> = None;
             if let Some(libpython) = libmap {
                 if let Some(filename) = &libpython.filename() {
-                    info!("Found libpython binary @ {}", filename);
+                    info!("Found libpython binary @ {}", filename.display());
                     #[allow(unused_mut)]
                     let mut parsed = parse_binary(process.pid, filename, libpython.start() as u64, libpython.size() as u64, false)?;
                     #[cfg(windows)]
@@ -831,15 +840,21 @@ impl PythonProcessInfo {
                         let segname = unsafe { std::ffi::CStr::from_ptr(dyld.segment.segname.as_ptr()) };
                         debug!("dyld: {:016x}-{:016x} {:10} {}",
                             dyld.segment.vmaddr, dyld.segment.vmaddr + dyld.segment.vmsize,
-                            segname.to_string_lossy(), dyld.filename);
+                            segname.to_string_lossy(), dyld.filename.display());
                     }
 
                     let python_dyld_data = dyld_infos.iter()
-                        .find(|m| is_python_framework(&m.filename) &&
-                                  m.segment.segname[0..7] == [95, 95, 68, 65, 84, 65, 0]);
+                        .find(|m| {
+                            if let Some(filename) = m.filename.to_str() {
+                                return is_python_framework(filename) &&
+                                      m.segment.segname[0..7] == [95, 95, 68, 65, 84, 65, 0];
+                            }
+                            false
+                        });
+
 
                     if let Some(libpython) = python_dyld_data {
-                        info!("Found libpython binary from dyld @ {}", libpython.filename);
+                        info!("Found libpython binary from dyld @ {}", libpython.filename.display());
 
                         let mut binary = parse_binary(process.pid, &libpython.filename, libpython.segment.vmaddr, libpython.segment.vmsize, false)?;
 
@@ -901,7 +916,7 @@ fn is_dockerized(pid: Pid) -> Result<bool, Error> {
 // So use the win32 api to load up the couple of symbols we need on windows. Note:
 // we still can get export's from the PE file
 #[cfg(windows)]
-pub fn get_windows_python_symbols(pid: Pid, filename: &str, offset: u64) -> std::io::Result<HashMap<String, u64>> {
+pub fn get_windows_python_symbols(pid: Pid, filename: &Path, offset: u64) -> std::io::Result<HashMap<String, u64>> {
     use proc_maps::win_maps::SymbolLoader;
 
     let handler = SymbolLoader::new(pid)?;
@@ -988,7 +1003,7 @@ mod tests {
         assert!(is_python_lib("/usr/local/lib/libpython3.8m.so"));
         assert!(is_python_lib("/usr/lib/libpython2.7u.so"));
 
-        // don't blindly match libraries with pytohn in the name (boost_python etc)
+        // don't blindly match libraries with python in the name (boost_python etc)
         assert!(!is_python_lib("/usr/lib/libboost_python.so"));
         assert!(!is_python_lib("/usr/lib/x86_64-linux-gnu/libboost_python-py27.so.1.58.0"));
         assert!(!is_python_lib("/usr/lib/libboost_python-py35.so"));
